==> openjdk-19_19~23ea.orig.tar.xz: openjdk-19-19~23ea/test/jdk/java/beans/XMLEncoder/javax_swing_border_StrokeBorder.java <==
/*
 * Copyright (c) 2010, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug 4358979
 * @summary Tests StrokeBorder encoding
 * @run main/othervm -Djava.security.manager=allow javax_swing_border_StrokeBorder
 * @author Sergey Malenkov
 */

import java.awt.BasicStroke;
import java.awt.Color;
import javax.swing.border.StrokeBorder;

public final class javax_swing_border_StrokeBorder extends AbstractTest<StrokeBorder> {
    public static void main(String[] args) {
        new javax_swing_border_StrokeBorder().test(true);
    }

    protected StrokeBorder getObject() {
        return new StrokeBorder(new BasicStroke(0), Color.WHITE);
    }

    protected StrokeBorder getAnotherObject() {
        return null; // TODO: could not update property
        //return new StrokeBorder(new BasicStroke(1));
    }
}

==> openjdk-25_25~10ea.orig.tar.xz: openjdk-25-25~10ea/test/jdk/java/beans/XMLEncoder/javax_swing_border_StrokeBorder.java <==
/*
 * Copyright (c) 2010, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug 4358979
 * @summary Tests StrokeBorder encoding
 * @run main/othervm javax_swing_border_StrokeBorder
 * @author Sergey Malenkov
 */

import java.awt.BasicStroke;
import java.awt.Color;
import javax.swing.border.StrokeBorder;

public final class javax_swing_border_StrokeBorder extends AbstractTest<StrokeBorder> {
    public static void main(String[] args) {
        new javax_swing_border_StrokeBorder().test();
    }

    protected StrokeBorder getObject() {
        return new StrokeBorder(new BasicStroke(0), Color.WHITE);
    }

    protected StrokeBorder getAnotherObject() {
        return null; // TODO: could not update property
        //return new StrokeBorder(new BasicStroke(1));
    }
}
